@@ -107,10 +107,13 @@ class UserProfile:
             "id": str(self.user_id),
             "name": self.name,
             "gender": self.gender.name,
-            "home_address": self.home_address.to_dict(),
-            "work_address": self.work_address.to_dict(),
         }
 
+        if self.home_address:
+            rv["home_address"] = self.home_address.to_dict()
+        if self.work_address:
+            rv["work_address"] = self.work_address.to_dict()
+
         if self.zone_id:
             rv["zone_id"] = self.zone_id
         if self.dob:
