@@ -54,6 +54,21 @@ def test_user_profile_to_dict():
         assert user_profile_dict[key] == user_profile_new_dict[key]
 
 
+def test_user_profile_with_no_home_work_address_to_dict():
+    user_profile = UserProfile.from_dict(user_profile_dict_with_no_home_or_work_address)
+    user_profile_new_dict = user_profile.to_dict()
+
+    for key in [
+        "id",
+        "name",
+        "gender",
+    ]:
+        assert (
+            user_profile_dict_with_no_home_or_work_address[key]
+            == user_profile_new_dict[key]
+        )
+
+
 def test_dict_to_session():
     session = Session.from_dict(session_response)
     assert session.user.id == "30944af3-dfe7-45e5-a860-31ac4a18bc69"
@@ -236,6 +251,12 @@ user_profile_dict = {
     "user_specific_features": ["AUTO_BOOKING"],
 }
 
+user_profile_dict_with_no_home_or_work_address = {
+    "id": "f77971a6-3a7f-4475-81b6-2fe9e085f0bc",
+    "gender": "MALE",
+    "name": "Test",
+}
+
 incomplete_user_profile_dict = {
     "created_at": "2018-10-18T13:04:55.643673",
     "home_address": {
